==> com.liferay.message.boards.service-4.0.44-sources.jar: com/liferay/message/boards/internal/model/listener/MBDiscussionStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.message.boards.internal.model.listener;

import com.liferay.message.boards.model.MBDiscussion;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class MBDiscussionStagingModelListener
	extends BaseModelListener<MBDiscussion> {

	@Override
	public void onAfterCreate(MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(mbDiscussion);
	}

	@Override
	public void onAfterRemove(MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(mbDiscussion);
	}

	@Override
	public void onAfterUpdate(MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(mbDiscussion);
	}

	@Reference
	private StagingModelListener<MBDiscussion> _stagingModelListener;

}

==> com.liferay.message.boards.service-5.0.52-sources.jar: com/liferay/message/boards/internal/model/listener/MBDiscussionStagingModelListener.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.message.boards.internal.model.listener;

import com.liferay.message.boards.model.MBDiscussion;
import com.liferay.portal.kernel.exception.ModelListenerException;
import com.liferay.portal.kernel.model.BaseModelListener;
import com.liferay.portal.kernel.model.ModelListener;
import com.liferay.staging.model.listener.StagingModelListener;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Akos Thurzo
 */
@Component(immediate = true, service = ModelListener.class)
public class MBDiscussionStagingModelListener
	extends BaseModelListener<MBDiscussion> {

	@Override
	public void onAfterCreate(MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterCreate(mbDiscussion);
	}

	@Override
	public void onAfterRemove(MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterRemove(mbDiscussion);
	}

	@Override
	public void onAfterUpdate(
			MBDiscussion originalMBDiscussion, MBDiscussion mbDiscussion)
		throws ModelListenerException {

		_stagingModelListener.onAfterUpdate(mbDiscussion);
	}

	@Reference
	private StagingModelListener<MBDiscussion> _stagingModelListener;

}
